@@ -1,6 +1,5 @@
 import asyncio
 import copy
-import json
 from datetime import date, timedelta
 from typing import Dict, Tuple
 
@@ -12,11 +11,14 @@ from liualgotrader.common import config
 from liualgotrader.common.data_loader import DataLoader  # type: ignore
 from liualgotrader.common.database import fetch_as_dataframe
 from liualgotrader.common.tlog import tlog
+from liualgotrader.common.types import AssetType
 from liualgotrader.models.accounts import Accounts
 from liualgotrader.models.optimizer import OptimizerRun
 from liualgotrader.models.portfolio import Portfolio
 from liualgotrader.trading.trader_factory import trader_factory
 
+AssetType
+
 est = timezone("America/New_York")
 
 
@@ -133,7 +135,8 @@ async def aload_trades_by_batch_id(batch_id: str) -> pd.DataFrame:
         WHERE 
             t.algo_run_id = a.algo_run_id AND 
             a.batch_id = '{batch_id}' AND
-            t.expire_tstamp is null 
+            t.expire_tstamp is null AND 
+            price != 0.0 
         ORDER BY symbol, tstamp
     """
     df: pd.DataFrame = await fetch_as_dataframe(query)
@@ -157,6 +160,8 @@ async def aload_trades_by_portfolio_id(portfolio_id: str) -> pd.DataFrame:
             t.algo_run_id = a.algo_run_id AND 
             a.batch_id = p.batch_id AND
             p.portfolio_id = '{portfolio_id}' AND
+            price != 0.0 AND 
+            target_price is not null AND
             t.expire_tstamp is null 
         ORDER BY symbol, tstamp
     """
@@ -281,24 +286,21 @@ def count_trades(symbol, trades: pd.DataFrame, batch_id: str) -> int:
 
 def trades_analysis(trades: pd.DataFrame, batch_id: str) -> pd.DataFrame:
     day_to_analyze = min(trades["client_time"].tolist())
-    config.market_open = day_to_analyze.replace(
-        hour=9, minute=30, second=0, microsecond=0
-    )
-    trades_anlytics = pd.DataFrame()
+    trades_analytics = pd.DataFrame()
     trades["client_time"] = pd.to_datetime(trades["client_time"], utc=True)
-    trades_anlytics["symbol"] = trades.symbol.unique()
-    trades_anlytics["revenues"] = trades_anlytics["symbol"].apply(
+    trades_analytics["symbol"] = trades.symbol.unique()
+    trades_analytics["revenues"] = trades_analytics["symbol"].apply(
         lambda x: calc_batch_revenue(x, trades, batch_id)
     )
-    trades_anlytics["count"] = trades_anlytics["symbol"].apply(
+    trades_analytics["count"] = trades_analytics["symbol"].apply(
         lambda x: count_trades(x, trades, batch_id)
     )
 
-    return trades_anlytics
+    return trades_analytics
 
 
-def symobl_trade_analytics(
-    symbol_df: pd.DataFrame, open_price: float, plt
+def symbol_trade_analytics(
+    symbol_df: pd.DataFrame, plt
 ) -> Tuple[pd.DataFrame, float]:
 
     d = copy.deepcopy(symbol_df).drop(
@@ -323,7 +325,7 @@ def symobl_trade_analytics(
 
     for _, row in symbol_df.iterrows():
         plt.scatter(
-            row["client_time"],
+            row["client_time"],  # .tz_convert("US/Eastern"),
             row["price"],
             c="g" if row["operation"] == "buy" else "r",
             s=100,
@@ -339,8 +341,12 @@ def calc_symbol_trades_returns(
     data_loader: DataLoader,
 ):
     t1 = t2 = None
-    qty: int = 0
-    eastern = timezone("US/Eastern")
+    qty: float = 0.0
+    eastern = timezone(
+        "US/Eastern",
+    )
+
+    symbol_trades["qty"] = symbol_trades["qty"].astype(float)
     for _, row in symbol_trades.iterrows():
         if t1 is None:
             t1 = daily_returns.index.get_loc(str(row.client_time.date()))
@@ -354,7 +360,7 @@ def calc_symbol_trades_returns(
                     * data_loader[symbol].close[
                         eastern.localize(
                             daily_returns.index[i].to_pydatetime()
-                        ).replace(hour=9, minute=30)
+                        ).replace(hour=9, minute=30, second=0, microsecond=0)
                     ]
                 )
                 daily_returns.loc[
@@ -373,27 +379,49 @@ def calc_symbol_trades_returns(
             t1 = t2
             t2 = None
 
-    if qty and t1:
+    if qty and t1 is not None:
         for i in range(t1, len(daily_returns.index)):
-            value = (
-                qty
-                * data_loader[symbol].close[
-                    eastern.localize(
-                        daily_returns.index[i].to_pydatetime()
-                    ).replace(hour=9, minute=30)
-                ]
-            )
+            try:
+                value = (
+                    qty
+                    * data_loader[symbol].close[
+                        eastern.localize(
+                            daily_returns.index[i].to_pydatetime()
+                        ).replace(hour=9, minute=30, second=0, microsecond=0)
+                    ]
+                )
+            except ValueError:
+                print("qty:", qty, t1)
+                raise
             daily_returns.loc[daily_returns.index[i], "equity"] += value
 
 
+def calc_symbol_state(
+    symbol: str,
+    symbol_trades: pd.DataFrame,
+    data_loader: DataLoader,
+) -> Tuple[float, float]:
+    qty: float = 0
+    for _, row in symbol_trades.iterrows():
+        if row.operation == "buy":
+            qty += row.qty
+        elif row.operation == "sell":
+            qty -= row.qty
+
+    return qty, data_loader[symbol].close[-1]
+
+
 def calc_batch_returns(batch_id: str) -> pd.DataFrame:
     loop = asyncio.get_event_loop()
     portfolio = loop.run_until_complete(Portfolio.load_by_batch_id(batch_id))
     data_loader = DataLoader()
     trades = load_trades_by_batch_id(batch_id)
+
+    if trades.empty:
+        return pd.DataFrame()
     start_date = trades.client_time.min().date()
     end_date = trades.client_time.max().date()
-    trader = trader_factory()()
+    trader = trader_factory()
 
     td = trader.get_trading_days(start_date=start_date, end_date=end_date)
 
@@ -420,7 +448,7 @@ def compare_to_symbol_returns(portfolio_id: str, symbol: str) -> pd.DataFrame:
     trades = load_trades_by_portfolio(portfolio_id)
     start_date = trades.client_time.min().date()
     end_date = trades.client_time.max().date()
-    trader = trader_factory()()
+    trader = trader_factory()
 
     td = trader.get_trading_days(start_date=start_date, end_date=end_date)
     td[symbol] = td.apply(
@@ -446,27 +474,28 @@ def get_cash(account_id: int, initial_cash: float) -> pd.DataFrame:
 
 def calc_portfolio_returns(portfolio_id: str) -> pd.DataFrame:
     loop = asyncio.get_event_loop()
-    _ = loop.run_until_complete(Portfolio.load_by_portfolio_id(portfolio_id))
-
-    try:
-        account_id, initial_account_size = loop.run_until_complete(
-            Portfolio.load_details(portfolio_id)
-        )
-    except Exception:
-        print("ERROR loading portfolio-id, please verify id and re-run.")
-        return pd.DataFrame()
+    portfolio = loop.run_until_complete(
+        Portfolio.load_by_portfolio_id(portfolio_id)
+    )
 
     data_loader = DataLoader()
     trades = load_trades_by_portfolio(portfolio_id)
+
+    if trades.empty:
+        return pd.DataFrame()
     start_date = trades.client_time.min().date()
     end_date = trades.client_time.max().date()
-    trader = trader_factory()()
+    trader = trader_factory()
 
-    td = trader.get_trading_days(start_date=start_date, end_date=end_date)
+    if portfolio.asset_type == AssetType.US_EQUITIES:
+        td = trader.get_trading_days(start_date=start_date, end_date=end_date)
+    else:
+        td = pd.DataFrame(index=pd.date_range(start_date, end_date))
 
     td["equity"] = 0.0
 
-    cash_df = get_cash(account_id, initial_account_size)
+    cash_df = get_cash(portfolio.account_id, portfolio.portfolio_size)
+
     symbols = trades.symbol.unique().tolist()
     for i in tqdm(
         range(len(symbols)), desc=f"loading portfolio {portfolio_id}"
@@ -493,6 +522,10 @@ def calc_hyperparameters_analysis(optimizer_run_id: str) -> pd.DataFrame:
     if len(portfolio_ids):
         for i in tqdm(range(len(portfolio_ids)), desc="Loading Portfolios"):
             _df = calc_portfolio_returns(portfolio_ids[i])
+
+            if _df.empty:
+                continue
+
             _df["portfolio_id"] = portfolio_ids[i]
             _df["configurations"] = hypers[i]
             _df.reset_index(inplace=True)
@@ -500,3 +533,51 @@ def calc_hyperparameters_analysis(optimizer_run_id: str) -> pd.DataFrame:
             df = pd.concat([df, _df], axis=0) if df is not None else _df
 
     return df
+
+
+def get_portfolio_equity(portfolio_id: str) -> pd.DataFrame:
+    loop = asyncio.get_event_loop()
+    portfolio = loop.run_until_complete(
+        Portfolio.load_by_portfolio_id(portfolio_id)
+    )
+    data_loader = DataLoader()
+    trades = load_trades_by_portfolio(portfolio_id)
+
+    symbols = trades.symbol.unique().tolist()
+    rows = []
+    for i in tqdm(
+        range(len(symbols)), desc=f"loading portfolio {portfolio_id}"
+    ):
+        symbol = symbols[i]
+        symbol_trades = trades[trades.symbol == symbol].sort_values(
+            by="client_time"
+        )
+        try:
+            qty, last_price = calc_symbol_state(
+                symbol, symbol_trades, data_loader
+            )
+        except Exception as e:
+            tlog(str(e))
+        else:
+            rows.append(
+                {
+                    "symbol": symbol,
+                    "qty": qty,
+                    "price": last_price,
+                    "total": float(qty) * last_price,
+                }
+            )
+
+    df = pd.DataFrame(rows)
+    return df.loc[df.qty > 0].round(2)
+
+
+def get_portfolio_cash(portfolio_id: str) -> pd.DataFrame:
+    loop = asyncio.get_event_loop()
+    portfolio = loop.run_until_complete(
+        Portfolio.load_by_portfolio_id(portfolio_id)
+    )
+
+    return loop.run_until_complete(
+        Accounts.get_transactions(portfolio.account_id)
+    ).round(2)
