@@ -19,24 +19,23 @@ env: str
 
 data_connector: DataConnectorType = DataConnectorType[os.getenv("DATA_CONNECTOR", "alpaca")]  # type: ignore
 
+# Performance, Debugging & Logging
+trace_enabled = bool(int(os.getenv("LIU_TRACE_ENABLED", 0)))
+debug_enabled = bool(int(os.getenv("LIU_DEBUG_ENABLED", 0)))
+gcp_logger = bool(int(os.getenv("GCP_STACKDRIVER", 0)))
+
 #
 # Broker
 #
-broker: BrokerType = BrokerType.alpaca
-#
-# Market Schedule
-#
-bypass_market_schedule: bool
-market_open: datetime
-market_close: datetime
+broker: BrokerType = BrokerType[os.getenv("LIU_BROKER", "alpaca")]
 
 # total number of tickers to follow
-total_tickers = int(os.getenv("LIU_MAX_SYMBOLS", "100"))
+total_tickers = 000
 
 #
 # Shared data
 #
-build_label: str
+build_label: str = "xoxo"
 filename: str
 db_conn_pool: Pool
 batch_id: str
@@ -46,7 +45,8 @@ batch_id: str
 #
 # Replace these with your API connection info from the dashboard
 polygon_api_key = os.getenv("POLYGON_API_KEY")
-alpaca_base_url = os.getenv("ALPACA_BASEURL")
+alpaca_base_url = os.getenv("APCA_API_BASE_URL")
+alpaca_crypto_base_url = "https://data.alpaca.markets/v1beta1/crypto"
 alpaca_api_key = os.getenv("APCA_API_KEY_ID")
 alpaca_api_secret = os.getenv("APCA_API_SECRET_KEY")
 alpaca_data_feed = os.getenv("ALPACA_DATA_FEED", "sip")
