@@ -1,5 +1,3 @@
-from typing import Dict
-
 import asyncpg
 import pandas as pd
 
@@ -8,20 +6,21 @@ from liualgotrader.common.tlog import tlog
 
 
 async def create_db_connection(dsn: str = None) -> None:
+    # if not hasattr(config, "db_conn_pool"):
+    _dsn = dsn or config.dsn
     config.db_conn_pool = await asyncpg.create_pool(
-        dsn=dsn or config.dsn,
+        dsn=_dsn,
         min_size=2,
-        max_size=40,
+        max_size=10,
     )
 
-    tlog("db connection pool initialized")
+    tlog(f"db connection pool initialized w {_dsn}")
 
 
 async def fetch_as_dataframe(query: str, *args) -> pd.DataFrame:
     try:
-        if config.db_conn_pool:
-            pass
-    except AttributeError:
+        config.db_conn_pool
+    except (NameError, AttributeError):
         await create_db_connection()
 
     async with config.db_conn_pool.acquire() as con:
