@@ -1,10 +1,10 @@
 from liualgotrader.common import config
-from liualgotrader.common.types import DataConnectorType, QueueMapper
+from liualgotrader.common.types import DataConnectorType
 from liualgotrader.data.alpaca import AlpacaData, AlpacaStream
 from liualgotrader.data.data_base import DataAPI
 from liualgotrader.data.finnhub import FinnhubData
+from liualgotrader.data.gemini import GeminiData, GeminiStream
 from liualgotrader.data.polygon import PolygonData, PolygonStream
-from liualgotrader.data.streaming_base import StreamingAPI
 
 
 def data_loader_factory(connector: DataConnectorType = None) -> DataAPI:
@@ -15,8 +15,10 @@ def data_loader_factory(connector: DataConnectorType = None) -> DataAPI:
         return AlpacaData()
     elif _connector == DataConnectorType.finnhub:
         return FinnhubData()
+    elif _connector == DataConnectorType.gemini:
+        return GeminiData()
     else:
-        raise Exception(f"unsupported data provider {config.data_connector}")
+        raise Exception(f"unsupported data provider {_connector}")
 
 
 def streaming_factory(connector: DataConnectorType = None):
@@ -25,7 +27,7 @@ def streaming_factory(connector: DataConnectorType = None):
         return PolygonStream
     elif _connector == DataConnectorType.alpaca:
         return AlpacaStream
+    elif _connector == DataConnectorType.gemini:
+        return GeminiStream
     else:
-        raise Exception(
-            f"unsupported streaming provider {config.data_connector}"
-        )
+        raise Exception(f"unsupported streaming provider {_connector}")
